#!/usr/bin/python
#
# yum-plugin-fiflock 0.1
#
# Copyright (c) 2014 Philippe Troin <phil@fifi.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

import collections
import re

from yum.plugins import TYPE_CORE

requires_api_version = '2.1'
plugin_type = (TYPE_CORE,)

def _isFifPackage(pkg):
    return re.match('^.*\.fif[0-9]+(?:\..*)?$', pkg.release) is not None

def exclude_hook(conduit):
    cnt = 0
    allrepos = conduit.getRepos().listEnabled()

    pkgdict = collections.defaultdict(lambda: [0, 0])

    for repo in allrepos:
	if repo.enabled:
	    for pkg in conduit.getPackages(repo):
		bucket = 0
		if _isFifPackage(pkg):
		    bucket=1
		pkgdict[pkg.name][bucket] += 1

    for repo in allrepos:
	if repo.enabled:
	    for pkg in conduit.getPackages(repo):
		if (pkgdict[pkg.name][1] > 0
		    and pkgdict[pkg.name][0] > 0
		    and not _isFifPackage(pkg)):
		    conduit.delPackage(pkg)
		    cnt += 1
		    conduit.info(3," --> %s from %s excluded (fiflock)" % (pkg,pkg.repoid))

    if cnt:
	conduit.info(2, '%d packages excluded due to fiflock' % cnt)
